local dewdrop = AceLibrary("Dewdrop-2.0");
local tablet = AceLibrary("Tablet-2.0");
---------------------
-- Options Support --
---------------------


function Yata:InitOptions()
	local options = {
		type="group",   
		args = {
			totembar = {                                                                             																																																																																																															
				name = "Totembar",                                                               																																																																																																															
				desc = Yata.L["Totembar configuration"],                                          																																																																																																															
				type = "group",
				args = {  
					lock = {
						name = Yata.L["Lock the frame"],
						desc = Yata.L["Lock the frame"],
						type = "toggle",
						get = function() return self.db.profile.Locked end,
						set = function(v)
							self.db.profile.Locked = v;
							if(self.IsInitialized) then
								if(v) then
									self.TotemBar.Header.Frame.Texture:Hide();
								else 	
									self.TotemBar.Header.Frame.Texture:Show();
								end
								self.TotemBar:SaveConfig();
							end
						end,
						disabled = function() return InCombatLockdown() end,
					},
					buttonlock = {
						name = Yata.L["Button Lock"],
						type = "toggle",
						desc = Yata.L["Button Lock"],
						get = function() return self.db.profile.ButtonLocked end,
						set = function(v)
							self.db.profile.ButtonLocked = v;
							if(self.IsInitialized) then
								self.TotemBar:SetupSwap(v);
								self:EditMacro();
							end
						end,
						disabled = function() return InCombatLockdown() end,
					},
					scale = {
						name = Yata.L["Button Scale"],
						desc = Yata.L["Scale the buttons"],
						type = "range",
						get = function() return self.db.profile.ButtonScale end,
						set = function(v)
							self.db.profile.ButtonScale = v;
							if(self.IsInitialized) then
								self.TotemBar.Header.Frame:SetScale(self.db.profile.ButtonScale);
								self.TotemBar:SaveConfig();
							end
						end,
						min = 0.5,
						max = 1.5,
						step = 0.05,
						disabled = function() return InCombatLockdown() end,
					},
					popupscale = {
						name = Yata.L["Popup Button Scale"],
						desc = Yata.L["Scale the popup buttons"],
						type = "range",
						get = function() return self.db.profile.PopupButtonScale end,
						set = function(v)
							self.db.profile.PopupButtonScale = v;
							if(self.IsInitialized) then
								for k,b in pairs(self.TotemBar.Buttons) do
									if(b.ButtonID > 10) then
										b.Frame:SetScale(self.db.profile.PopupButtonScale);
									end
								end
								self.TotemBar:SaveConfig();
							end
						end,
						min = 0.5,
						max = 1.0,
						step = 0.05,
						disabled = function() return InCombatLockdown() end,
					},
					invertbar = {
						name = Yata.L["Invert bar direction"],
						desc = Yata.L["Invert bar direction"],
						type = "toggle",
						get = function() return self.db.profile.InvertBar end,
						set = function(v)
							self.db.profile.InvertBar = v;
							if(self.IsInitialized) then
								self:Print("You'll need to /console reloadui now");
								self.TotemBar:SaveConfig();
							end
						end,
						disabled = function() return InCombatLockdown() end,
						},
					},
				disabled = function() return InCombatLockdown() end, 
			},
			tooltips = {
				name = "Tooltips",
				desc = Yata.L["Tooltip configuration"],
				type = "group",
				args = {
					showtooltip = {
						name = Yata.L["Show Tooltip"],
						type = "toggle",
						desc = Yata.L["Show Tooltip"],
						get = function() return self.db.profile.ShowTooltip end,
						set = function(v)
							self.db.profile.ShowTooltip = v;
							self.db.profile.ShowTTOOC = v;
							if(self.IsInitialized) then
								self.TotemBar:SaveConfig();
							end
						end,
					},
					showooconly = {
						name = Yata.L["Out of combat only"],
						type = "toggle",
						desc = Yata.L["Out of combat only"],
						get = function() return self.db.profile.ShowTTOOC end,
						set = function(v)
							self.db.profile.ShowTTOOC = v;
							if(self.IsInitialized) then
								self.TotemBar:SaveConfig();
							end
						end,
					},			
				},
				disabled = function() return InCombatLockdown() end,
			},			
			totemsets = {
				name = "Totemsets",
				desc = "Totemsets",
				type = "group",
				args = {
					header = { 
						type = "header",
						name = "No active Set",
						order = 1,
					},
					addset = {
						name = "Add",
						desc = "Add",
						type = "execute",
						func = function()
							self.TotemBar.EditSet = true; 
							self.TotemBar:SetupSwap(nil);
							self.TotemBar:SaveConfig();
							self.db.profile.ButtonLocked = false;
							StaticPopup_Show("YataAddSet");
						end,
					},
					loadset = {
						name = "Load",
						desc = "Load Set",
						type = "group",
						args = {},
						disabled = function() return next(Yata.options.args.totemsets.args.loadset.args) == nil end
					},
					deleteset = {
						name = "Delete",
						desc = "Delete Set",
						type = "group",
						args = {},
						disabled = function() return next(Yata.options.args.totemsets.args.deleteset.args) == nil end
					},
					reset = {
						name = "Switch to default layout",
						desc = "Switch to default layout",
						type = "execute",
						func = function() self.TotemBar:ResetSet(); end,
					},
				},
				disabled = function() return InCombatLockdown() end,
			},
			keybindings = {
				name = "Keybindings",
				desc = "Keybindings",
				type = "group",
				args = {},
				disabled = function() return InCombatLockdown() end,
			},
			totemtimers = {
				name = "Totem Timers",
				desc = "Totem Timers",
				type = "group",
				args = {},
				disabled = function() return InCombatLockdown() end,
			}
		}
	};
	self:InitDialogs();
	Yata.OnMenuRequest = options;
	return options;
end

-- Originally found in Closetgnome by Rabbit
function Yata:InitDialogs()
	if not StaticPopupDialogs then
		StaticPopupDialogs = {}
	end
	StaticPopupDialogs["YataAddSet"] = {
		text = "Please enter the name for your Set, it the name is already existing the two Sets will be merged, any changes to the button layout will be now done on this set.",
		button1 = "Add",
		button2 = "Cancel",
		OnCancel = function() self.TotemBar:SetupSwap(true); self.db.profile.ButtonLocked = true; self.TotemBar.EditSet = false; end,
		sound = "levelup2",
		whileDead = 1,
		hideOnEscape = 1,
		timeout = 0,
		OnShow = function()
			-- We have to do this onshow to reset the previous text
			_G[this:GetName().."EditBox"]:SetText("")
		end,
		OnAccept = function()
			local name = _G[this:GetParent():GetName().."EditBox"]:GetText()
			self.TotemBar:AddTotemSet(name);
			self.TotemBar:SetupSwap(true);
			self.db.profile.ButtonLocked = true;
			self.TotemBar.EditSet = false;
		end,
		hasEditBox = 1,
	}
	StaticPopupDialogs["YataDeleteSet"] = {
		text = "Are you sure you want to delete the set %s?",
		button1 = "Delete",
		button2 = "Cancel",
		showAlert = 1,
		timeout = 0,
		OnAccept = function() self.TotemBar:DeleteTotemSet(); end,
		OnCancel = function() end,
	}

end

-------------
-- Profile --
-------------
function Yata:InitProfile()
	-- TotemsOrder
	if(not self.db.profile.TotemsOrder) then
		self.db.profile.TotemsOrder = {"Earth","Air","Water","Fire"};
		for i=1,4 do
			self.db.profile.TotemsOrder[self.db.profile.TotemsOrder[i]] = {};
		end
	end
	-- TotemSets, ActiveSet
	if(not self.db.profile.TotemSets) then self.db.profile.TotemSets = {} end;
	if(not self.db.profile.ActiveSet) then self.db.profile.ActiveSet = ""; end;
end
-----------
-- FuBar --
-----------


function Yata:OnTextUpdate()
    if(self.db.profile.ActiveSet ~= "" and self.db.profile.ActiveSet) then
    	self:SetText(self.db.profile.ActiveSet);
    else
    	self:SetText("No Set");
    end
end

-- originally found in ClosetGnome by rabbit
function Yata:OnTooltipUpdate()
	local cat = nil;
	local function clickfunc(name)
		if(name == "" and self.db.profile.ActiveSet ~= "") then
			self.TotemBar:ResetSet();
		else 
			self.TotemBar:LoadTotemSet(name);
		end
		Yata:UpdateTooltip();
	end
	local sets = {};
	for k in pairs(self.db.profile.TotemSets) do table.insert(sets, k) end;
	table.sort(sets);
	for i, set in ipairs(sets) do
		if (not cat) then
			cat = tablet:AddCategory(
				"text", "Available Totemsets",
				"showWithoutChildren", false,
				"child_hasCheck", true,
				"child_checked", false,
				"child_isRadio", true
			);
		end
		local displayName = "  "..set;
		local checked = false;
		if(self.db.profile.ActiveSet == set) then
			checked = true;
		end
		cat:AddLine(
			"text", displayName,
			"func", clickfunc,
			"arg1", set,
			"checked", checked
		);
	end
	local checked = false;
	if(self.db.profile.ActiveSet == "") then
		checked = true;
	end
	if(cat) then
		cat:AddLine("text", "  No Set", "func", clickfunc, "arg1", "", "checked", checked);
	end
	sets = nil;

	if (cat ~= nil) then
		tablet:SetHint("Please click on any Set Name to equip or click on 'No Set' to return to the default Totembar");
	else
		tablet:SetHint("No Totemsets created");
	end
end

-----------------
-- Macro Stuff --
-----------------

function Yata:EditMacro()
	if(InCombatLockdown()) then return end;
	local num = GetNumMacros();
	local numIcons = GetNumMacroIcons();
	local iconid = 0;
	for i=1,numIcons do
		if(GetMacroIconInfo(i) == "Interface\\Icons\\Spell_Nature_EarthBindTotem") then
			iconid = i;
			break;
		end  
	end
	if(iconid == 0) then Yata:Print("Couldn't find Icon"); return end;
	local macro = "/castsequence reset=combat/shift "..self.TotemBar.Buttons[1].Totem.Name..", "..self.TotemBar.Buttons[2].Totem.Name..", "..self.TotemBar.Buttons[3].Totem.Name..", "..self.TotemBar.Buttons[4].Totem.Name..";"
	local macroindex = 0;
	if(num < 18) then
		macroindex = GetMacroIndexByName("YataTotemStomp");
		if(macroindex > 0) then
			EditMacro(macroindex, "YataTotemStomp",iconid,macro,1);
		else 
			CreateMacro("YataTotemStomp",iconid,macro,1,1);
		end
	else Yata:Print("No more Macros allowed");
	end
end